Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9989)

Unified Diff: chrome/renderer/render_view.cc

Issue 17281: This is a rename of the term 'Greasemonkey' to 'user script' in Chromium. (Closed)
Patch Set: Fix indent Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/render_view.h ('k') | chrome/renderer/renderer.scons » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/render_view.cc
diff --git a/chrome/renderer/render_view.cc b/chrome/renderer/render_view.cc
index c94e430ee08b4331b976f58bab2390daeaa9467e..abf8b4b9b492ef6a03a01ff532424bb6f675a576 100644
--- a/chrome/renderer/render_view.cc
+++ b/chrome/renderer/render_view.cc
@@ -28,9 +28,9 @@
#include "chrome/renderer/about_handler.h"
#include "chrome/renderer/chrome_plugin_host.h"
#include "chrome/renderer/debug_message_handler.h"
-#include "chrome/renderer/greasemonkey_slave.h"
#include "chrome/renderer/localized_error.h"
#include "chrome/renderer/renderer_resources.h"
+#include "chrome/renderer/user_script_slave.h"
#include "chrome/renderer/visitedlink_slave.h"
#include "chrome/renderer/webmediaplayer_delegate_impl.h"
#include "chrome/renderer/webplugin_delegate_proxy.h"
@@ -162,7 +162,7 @@ RenderView::RenderView(RenderThreadBase* render_thread)
disable_popup_blocking_(false),
has_unload_listener_(false),
decrement_shared_popup_at_destruction_(false),
- greasemonkey_enabled_(false),
+ user_scripts_enabled_(false),
waiting_for_create_window_ack_(false),
form_field_autofill_request_id_(0),
popup_notification_visible_(false),
@@ -294,8 +294,8 @@ void RenderView::Init(HWND parent_hwnd,
command_line.HasSwitch(switches::kDomAutomationController);
disable_popup_blocking_ =
command_line.HasSwitch(switches::kDisablePopupBlocking);
- greasemonkey_enabled_ =
- command_line.HasSwitch(switches::kEnableGreasemonkey);
+ user_scripts_enabled_ =
+ command_line.HasSwitch(switches::kEnableUserScripts);
debug_message_handler_ = new DebugMessageHandler(this);
render_thread_->AddFilter(debug_message_handler_);
@@ -1457,15 +1457,15 @@ void RenderView::DidFinishDocumentLoadForFrame(WebView* webview,
// Check whether we have new encoding name.
UpdateEncoding(frame, webview->GetMainFrameEncodingName());
- // Inject any Greasemonkey scripts. Do not inject into chrome UI pages, but
- // do inject into any other document.
- if (greasemonkey_enabled_) {
+ // Inject any user scripts. Do not inject into chrome UI pages, but do inject
+ // into any other document.
+ if (user_scripts_enabled_) {
const GURL &gurl = frame->GetURL();
if (g_render_thread && // Will be NULL when testing.
(gurl.SchemeIs("file") ||
gurl.SchemeIs("http") ||
gurl.SchemeIs("https"))) {
- g_render_thread->greasemonkey_slave()->InjectScripts(frame);
+ g_render_thread->user_script_slave()->InjectScripts(frame);
}
}
}
« no previous file with comments | « chrome/renderer/render_view.h ('k') | chrome/renderer/renderer.scons » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698